obelisk.types.QueryResult
=========================

.. currentmodule:: obelisk.types

.. autoclass:: QueryResult
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~QueryResult.__init__
      ~QueryResult.construct
      ~QueryResult.copy
      ~QueryResult.dict
      ~QueryResult.from_orm
      ~QueryResult.json
      ~QueryResult.model_construct
      ~QueryResult.model_copy
      ~QueryResult.model_dump
      ~QueryResult.model_dump_json
      ~QueryResult.model_json_schema
      ~QueryResult.model_parametrized_name
      ~QueryResult.model_post_init
      ~QueryResult.model_rebuild
      ~QueryResult.model_validate
      ~QueryResult.model_validate_json
      ~QueryResult.model_validate_strings
      ~QueryResult.parse_file
      ~QueryResult.parse_obj
      ~QueryResult.parse_raw
      ~QueryResult.schema
      ~QueryResult.schema_json
      ~QueryResult.update_forward_refs
      ~QueryResult.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~QueryResult.model_computed_fields
      ~QueryResult.model_config
      ~QueryResult.model_extra
      ~QueryResult.model_fields
      ~QueryResult.model_fields_set
      ~QueryResult.items
      ~QueryResult.cursor
   
   